# AnimalAI Python API

This package provides the Python API used for training agents for the Animal AI Olympics competition.

This library is mostly the same as [Unity's MLAgents](https://github.com/Unity-Technologies/ml-agents).